==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/Output/alsa/translations/alsa_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Модуль ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>Про модуль виводу ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Модуль виводу ALSA для Qmmp</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Параметри пристроїв</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Аудіо пристрій</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Mixer</source>
        <translation>Мікшер</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Mixer card:</source>
        <translation>Карта мікшера:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Mixer device:</source>
        <translation>Пристрій мікшера:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Advanced Settings</source>
        <translation>Додаткові налаштування</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="111"/>
        <source>Soundcard</source>
        <translation>Звукова карта</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Buffer time (ms):</source>
        <translation>Час буферизації (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="153"/>
        <source>Period time (ms):</source>
        <translation>Час періоду (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="209"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Використовувати функцію snd_pcm_pause</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Налаштування модуля ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="189"/>
        <source>Use mmap access</source>
        <translation>Використовувати доступ mmap</translation>
    </message>
</context>
</TS>

==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/Output/alsa/translations/alsa_plugin_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Модуль ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>Про модуль виводу ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Модуль виводу ALSA для Qmmp</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Розробник: Ілля Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Параметри пристроїв</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Аудіо пристрій</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Mixer</source>
        <translation>Мікшер</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Mixer card:</source>
        <translation>Карта мікшера:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>Mixer device:</source>
        <translation>Пристрій мікшера:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Advanced Settings</source>
        <translation>Додаткові налаштування</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="111"/>
        <source>Soundcard</source>
        <translation>Звукова карта</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>Buffer time (ms):</source>
        <translation>Час буферизації (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="153"/>
        <source>Period time (ms):</source>
        <translation>Час періоду (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="209"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Використовувати функцію snd_pcm_pause</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Налаштування модуля ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="189"/>
        <source>Use mmap access</source>
        <translation>Використовувати доступ mmap</translation>
    </message>
</context>
</TS>
